/****************************************************************************
*
*	Example Code for MNM1221
*
*	Copyright (c) 2004-2023 Panasonic Industry Co., Ltd.
*
*----------------------------------------------------------------------------
*
*	File Name:		mnm1221_m.h
*	Description:	Header file to access MNM1221 as MASTER mode
*   Notes:
*	- This code is just for reference, so that Panasonic does NOT assume 
*	  responsibility or liability for actual use based upon this code.
*	- This file is NOT for warranty of correct behavior, 
*	  and might include bugs, so that you have to be careful.
*	- It is assumed that TAB of your PC is set to 4space width.
*
*----------------------------------------------------------------------------
*	Revision:	Date(y/m/d):	Author:			Comments:
*	0.0			2004/03/01		Y. Fujisaki		Initial release
*	0.1			2005/05/20		Y. Fujisaki		Minor edits
*	0.2			2023/03/31		Y. Fujisaki		Added the registers for MDIO
*
*****************************************************************************/


/*** IMPORTANT!!! ***/
/* You must modify the following definition according to your system. */
/*--------------------------------------------------------------------------*/
/* Definition depend on your system											*/
/*--------------------------------------------------------------------------*/
/* Located Address of MNM1221 */
#define	ADDR_MNM1221		0x08000000		/* unit: byte address */

/* Data Bus Width to access to MNM1221 */
#define MASTER_16BIT_ACCESS
/* If NOT 16bits BUT 32bits, change this definition to comments or delete it. */
/*--------------------------------------------------------------------------*/


/*--------------------------------------------------------------------------*/
/* Definition of address value (unit: byte address) 						*/
/*--------------------------------------------------------------------------*/
/*--- for memory access ----------------------------------------------------*/
#define	ADDR_TX_MEM_BGN		(ADDR_MNM1221 + 0x0000)
#define	ADDR_RX_MEM_BGN		(ADDR_MNM1221 + 0x0200)

/*--- for MASTER control ---------------------------------------------------*/
#define	ADDR_M_RESET		(ADDR_MNM1221 + 0x0400)
#define	ADDR_M_INITF_TX		(ADDR_MNM1221 + 0x0404)
#define	ADDR_M_CYCL_START	(ADDR_MNM1221 + 0x0408)

#define	ADDR_M_RTF_FORM		(ADDR_MNM1221 + 0x0414)
#define	ADDR_M_ERR_COUNT	(ADDR_MNM1221 + 0x0418)
#define	ADDR_M_INIT_DONE	(ADDR_MNM1221 + 0x041C)
#define	ADDR_M_TXTIM_SEL	(ADDR_MNM1221 + 0x0420)
#define	ADDR_M_TX_PERIOD	(ADDR_MNM1221 + 0x0424)

#define	ADDR_M_TXMEM_SW		(ADDR_MNM1221 + 0x0458)
#define	ADDR_M_RXMEM_HOLD	(ADDR_MNM1221 + 0x045C)

#define	ADDR_M_MDIO_WDAT	(ADDR_MNM1221 + 0x0448)
#define	ADDR_M_MDIO_ADDR	(ADDR_MNM1221 + 0x044C)
#define	ADDR_M_MDIO_WR		(ADDR_MNM1221 + 0x0450)
#define	ADDR_M_MDIO_RD		(ADDR_MNM1221 + 0x0454)

/*--- for MASTER status ----------------------------------------------------*/
#define	ADDR_M_STATE		(ADDR_MNM1221 + 0x0484)

#define	ADDR_M_INIT_ERR		(ADDR_MNM1221 + 0x0488)
#define	ADDR_M_ERR_FLAGS1	(ADDR_MNM1221 + 0x0490)
#define	ADDR_M_ERR_FLAGS2	(ADDR_MNM1221 + 0x0494)
#define	ADDR_M_DCRC_ERR_L	(ADDR_MNM1221 + 0x0498)
#define	ADDR_M_DCRC_ERR_H	(ADDR_MNM1221 + 0x049A)

#define	ADDR_M_NODE_SUM		(ADDR_MNM1221 + 0x049C)
#define	ADDR_M_BLK_SUM		(ADDR_MNM1221 + 0x04A0)

#define	ADDR_M_SINF_0		(ADDR_MNM1221 + 0x04A4)
#define	ADDR_M_SINF_1		(ADDR_MNM1221 + 0x04A6)
#define	ADDR_M_SINF_2		(ADDR_MNM1221 + 0x04A8)
#define	ADDR_M_SINF_3		(ADDR_MNM1221 + 0x04AA)
#define	ADDR_M_SINF_4		(ADDR_MNM1221 + 0x04AC)
#define	ADDR_M_SINF_5		(ADDR_MNM1221 + 0x04AE)
#define	ADDR_M_SINF_6		(ADDR_MNM1221 + 0x04B0)
#define	ADDR_M_SINF_7		(ADDR_MNM1221 + 0x04B2)

#define	ADDR_M_SINF_8		(ADDR_MNM1221 + 0x04B4)
#define	ADDR_M_SINF_9		(ADDR_MNM1221 + 0x04B6)
#define	ADDR_M_SINF_10		(ADDR_MNM1221 + 0x04B8)
#define	ADDR_M_SINF_11		(ADDR_MNM1221 + 0x04BA)
#define	ADDR_M_SINF_12		(ADDR_MNM1221 + 0x04BC)
#define	ADDR_M_SINF_13		(ADDR_MNM1221 + 0x04BE)
#define	ADDR_M_SINF_14		(ADDR_MNM1221 + 0x04C0)
#define	ADDR_M_SINF_15		(ADDR_MNM1221 + 0x04C2)

#define	ADDR_M_SINF_16		(ADDR_MNM1221 + 0x04C4)
#define	ADDR_M_SINF_17		(ADDR_MNM1221 + 0x04C6)
#define	ADDR_M_SINF_18		(ADDR_MNM1221 + 0x04C8)
#define	ADDR_M_SINF_19		(ADDR_MNM1221 + 0x04CA)
#define	ADDR_M_SINF_20		(ADDR_MNM1221 + 0x04CC)
#define	ADDR_M_SINF_21		(ADDR_MNM1221 + 0x04CE)
#define	ADDR_M_SINF_22		(ADDR_MNM1221 + 0x04D0)
#define	ADDR_M_SINF_23		(ADDR_MNM1221 + 0x04D2)

#define	ADDR_M_SINF_24		(ADDR_MNM1221 + 0x04D4)
#define	ADDR_M_SINF_25		(ADDR_MNM1221 + 0x04D6)
#define	ADDR_M_SINF_26		(ADDR_MNM1221 + 0x04D8)
#define	ADDR_M_SINF_27		(ADDR_MNM1221 + 0x04DA)
#define	ADDR_M_SINF_28		(ADDR_MNM1221 + 0x04DC)
#define	ADDR_M_SINF_29		(ADDR_MNM1221 + 0x04DE)
#define	ADDR_M_SINF_30		(ADDR_MNM1221 + 0x04E0)
#define	ADDR_M_SINF_31		(ADDR_MNM1221 + 0x04E2)

#define	ADDR_M_MDIO_RDAT	(ADDR_MNM1221 + 0x04F8)
/*--------------------------------------------------------------------------*/


#ifdef MASTER_16BIT_ACCESS
/*--------------------------------------------------------------------------*/
/* Register definition for MASTER 16bit-bus access 							*/
/*--------------------------------------------------------------------------*/

/*--- pointer for memory copy ----------------------------------------------*/
#define	P_MNM1221_TX_MEM_BGN	((volatile unsigned short *)ADDR_TX_MEM_BGN)
#define	P_MNM1221_RX_MEM_BGN	((volatile unsigned short *)ADDR_RX_MEM_BGN)
#define	P_MNM1221_M_SINF_BGN	((volatile unsigned short *)ADDR_M_SINF_0)

/*--- for memory access ----------------------------------------------------*/
#define	MNM1221_TX_MEM_BGN		(*P_MNM1221_TX_MEM_BGN)
#define	MNM1221_RX_MEM_BGN		(*P_MNM1221_RX_MEM_BGN)

/*--- for control ----------------------------------------------------------*/
#define	MNM1221_M_RESET			(*((volatile unsigned short *)ADDR_M_RESET))
#define	MNM1221_M_INITF_TX		(*((volatile unsigned short *)ADDR_M_INITF_TX))
#define	MNM1221_M_CYCL_START	(*((volatile unsigned short *)ADDR_M_CYCL_START))

#define	MNM1221_M_RTF_FORM		(*((volatile unsigned short *)ADDR_M_RTF_FORM))
#define	MNM1221_M_ERR_COUNT		(*((volatile unsigned short *)ADDR_M_ERR_COUNT))
#define	MNM1221_M_INIT_DONE		(*((volatile unsigned short *)ADDR_M_INIT_DONE))
#define	MNM1221_M_TXTIM_SEL		(*((volatile unsigned short *)ADDR_M_TXTIM_SEL))
#define	MNM1221_M_TX_PERIOD		(*((volatile unsigned short *)ADDR_M_TX_PERIOD))

#define	MNM1221_M_TXMEM_SW		(*((volatile unsigned short *)ADDR_M_TXMEM_SW))
#define	MNM1221_M_RXMEM_HOLD	(*((volatile unsigned short *)ADDR_M_RXMEM_HOLD))

#define	MNM1221_M_MDIO_WDAT		(*((volatile unsigned short *)ADDR_M_MDIO_WDAT))
#define	MNM1221_M_MDIO_ADDR		(*((volatile unsigned short *)ADDR_M_MDIO_ADDR))
#define	MNM1221_M_MDIO_WR		(*((volatile unsigned short *)ADDR_M_MDIO_WR))
#define	MNM1221_M_MDIO_RD		(*((volatile unsigned short *)ADDR_M_MDIO_RD))

/*--- for status -----------------------------------------------------------*/
#define	MNM1221_M_STATE			(*((volatile unsigned short *)ADDR_M_STATE))

#define	MNM1221_M_INIT_ERR		(*((volatile unsigned short *)ADDR_M_INIT_ERR))
#define	MNM1221_M_ERR_FLAGS1	(*((volatile unsigned short *)ADDR_M_ERR_FLAGS1))
#define	MNM1221_M_ERR_FLAGS2	(*((volatile unsigned short *)ADDR_M_ERR_FLAGS2))
#define	MNM1221_M_DCRC_ERR_L	(*((volatile unsigned short *)ADDR_M_DCRC_ERR_L))
#define	MNM1221_M_DCRC_ERR_H	(*((volatile unsigned short *)ADDR_M_DCRC_ERR_H))

#define	MNM1221_M_NODE_SUM		(*((volatile unsigned short *)ADDR_M_NODE_SUM))
#define	MNM1221_M_BLK_SUM		(*((volatile unsigned short *)ADDR_M_BLK_SUM))

#define	MNM1221_M_SINF_0		(*P_MNM1221_M_SINF_BGN)
#define	MNM1221_M_SINF_1		(*((volatile unsigned short *)ADDR_M_SINF_1))
#define	MNM1221_M_SINF_2		(*((volatile unsigned short *)ADDR_M_SINF_2))
#define	MNM1221_M_SINF_3		(*((volatile unsigned short *)ADDR_M_SINF_3))
#define	MNM1221_M_SINF_4		(*((volatile unsigned short *)ADDR_M_SINF_4))
#define	MNM1221_M_SINF_5		(*((volatile unsigned short *)ADDR_M_SINF_5))
#define	MNM1221_M_SINF_6		(*((volatile unsigned short *)ADDR_M_SINF_6))
#define	MNM1221_M_SINF_7		(*((volatile unsigned short *)ADDR_M_SINF_7))

#define	MNM1221_M_SINF_8		(*((volatile unsigned short *)ADDR_M_SINF_8))
#define	MNM1221_M_SINF_9		(*((volatile unsigned short *)ADDR_M_SINF_9))
#define	MNM1221_M_SINF_10		(*((volatile unsigned short *)ADDR_M_SINF_10))
#define	MNM1221_M_SINF_11		(*((volatile unsigned short *)ADDR_M_SINF_11))
#define	MNM1221_M_SINF_12		(*((volatile unsigned short *)ADDR_M_SINF_12))
#define	MNM1221_M_SINF_13		(*((volatile unsigned short *)ADDR_M_SINF_13))
#define	MNM1221_M_SINF_14		(*((volatile unsigned short *)ADDR_M_SINF_14))
#define	MNM1221_M_SINF_15		(*((volatile unsigned short *)ADDR_M_SINF_15))

#define	MNM1221_M_SINF_16		(*((volatile unsigned short *)ADDR_M_SINF_16))
#define	MNM1221_M_SINF_17		(*((volatile unsigned short *)ADDR_M_SINF_17))
#define	MNM1221_M_SINF_18		(*((volatile unsigned short *)ADDR_M_SINF_18))
#define	MNM1221_M_SINF_19		(*((volatile unsigned short *)ADDR_M_SINF_19))
#define	MNM1221_M_SINF_20		(*((volatile unsigned short *)ADDR_M_SINF_20))
#define	MNM1221_M_SINF_21		(*((volatile unsigned short *)ADDR_M_SINF_21))
#define	MNM1221_M_SINF_22		(*((volatile unsigned short *)ADDR_M_SINF_22))
#define	MNM1221_M_SINF_23		(*((volatile unsigned short *)ADDR_M_SINF_23))

#define	MNM1221_M_SINF_24		(*((volatile unsigned short *)ADDR_M_SINF_24))
#define	MNM1221_M_SINF_25		(*((volatile unsigned short *)ADDR_M_SINF_25))
#define	MNM1221_M_SINF_26		(*((volatile unsigned short *)ADDR_M_SINF_26))
#define	MNM1221_M_SINF_27		(*((volatile unsigned short *)ADDR_M_SINF_27))
#define	MNM1221_M_SINF_28		(*((volatile unsigned short *)ADDR_M_SINF_28))
#define	MNM1221_M_SINF_29		(*((volatile unsigned short *)ADDR_M_SINF_29))
#define	MNM1221_M_SINF_30		(*((volatile unsigned short *)ADDR_M_SINF_30))
#define	MNM1221_M_SINF_31		(*((volatile unsigned short *)ADDR_M_SINF_31))

#define	MNM1221_M_MDIO_RDAT		(*((volatile unsigned short *)ADDR_M_MDIO_RDAT))
/*--------------------------------------------------------------------------*/


#else
/*--------------------------------------------------------------------------*/
/* Register definition for MASTER 32bit-bus access 							*/
/*--------------------------------------------------------------------------*/

/*--- pointer for memory copy ----------------------------------------------*/
#define	P_MNM1221_TX_MEM_BGN	((volatile unsigned long *)ADDR_TX_MEM_BGN)
#define	P_MNM1221_RX_MEM_BGN	((volatile unsigned long *)ADDR_RX_MEM_BGN)
#define	P_MNM1221_M_SINF_BGN	((volatile unsigned long *)ADDR_M_SINF_0)

/*--- for memory access ----------------------------------------------------*/
#define	MNM1221_TX_MEM_BGN		(*P_MNM1221_TX_MEM_BGN)
#define	MNM1221_RX_MEM_BGN		(*P_MNM1221_RX_MEM_BGN)

/*--- for control ----------------------------------------------------------*/
#define	MNM1221_M_RESET			(*((volatile unsigned long *)ADDR_M_RESET))
#define	MNM1221_M_INITF_TX		(*((volatile unsigned long *)ADDR_M_INITF_TX))
#define	MNM1221_M_CYCL_START	(*((volatile unsigned long *)ADDR_M_CYCL_START))

#define	MNM1221_M_RTF_FORM		(*((volatile unsigned long *)ADDR_M_RTF_FORM))
#define	MNM1221_M_ERR_COUNT		(*((volatile unsigned long *)ADDR_M_ERR_COUNT))
#define	MNM1221_M_INIT_DONE		(*((volatile unsigned long *)ADDR_M_INIT_DONE))
#define	MNM1221_M_TXTIM_SEL		(*((volatile unsigned long *)ADDR_M_TXTIM_SEL))
#define	MNM1221_M_TX_PERIOD		(*((volatile unsigned long *)ADDR_M_TX_PERIOD))

#define	MNM1221_M_TXMEM_SW		(*((volatile unsigned long *)ADDR_M_TXMEM_SW))
#define	MNM1221_M_RXMEM_HOLD	(*((volatile unsigned long *)ADDR_M_RXMEM_HOLD))

#define	MNM1221_M_MDIO_WDAT		(*((volatile unsigned long *)ADDR_M_MDIO_WDAT))
#define	MNM1221_M_MDIO_ADDR		(*((volatile unsigned long *)ADDR_M_MDIO_ADDR))
#define	MNM1221_M_MDIO_WR		(*((volatile unsigned long *)ADDR_M_MDIO_WR))
#define	MNM1221_M_MDIO_RD		(*((volatile unsigned long *)ADDR_M_MDIO_RD))

/*--- for status -----------------------------------------------------------*/
#define	MNM1221_M_STATE			(*((volatile unsigned long *)ADDR_M_STATE))

#define	MNM1221_M_INIT_ERR		(*((volatile unsigned long *)ADDR_M_INIT_ERR))
#define	MNM1221_M_ERR_FLAGS1	(*((volatile unsigned long *)ADDR_M_ERR_FLAGS1))
#define	MNM1221_M_ERR_FLAGS2	(*((volatile unsigned long *)ADDR_M_ERR_FLAGS2))
#define	MNM1221_M_DCRC_ERR		(*((volatile unsigned long *)ADDR_M_DCRC_ERR_L))

#define	MNM1221_M_NODE_SUM		(*((volatile unsigned long *)ADDR_M_NODE_SUM))
#define	MNM1221_M_BLK_SUM		(*((volatile unsigned long *)ADDR_M_BLK_SUM))

#define	MNM1221_M_SINF_1_0		(*P_MNM1221_M_SINF_BGN)
#define	MNM1221_M_SINF_3_2		(*((volatile unsigned long *)ADDR_M_SINF_2))
#define	MNM1221_M_SINF_5_4		(*((volatile unsigned long *)ADDR_M_SINF_4))
#define	MNM1221_M_SINF_7_6		(*((volatile unsigned long *)ADDR_M_SINF_6))
#define	MNM1221_M_SINF_9_8		(*((volatile unsigned long *)ADDR_M_SINF_8))
#define	MNM1221_M_SINF_11_10	(*((volatile unsigned long *)ADDR_M_SINF_10))
#define	MNM1221_M_SINF_13_12	(*((volatile unsigned long *)ADDR_M_SINF_12))
#define	MNM1221_M_SINF_15_14	(*((volatile unsigned long *)ADDR_M_SINF_14))

#define	MNM1221_M_SINF_17_16	(*((volatile unsigned long *)ADDR_M_SINF_16))
#define	MNM1221_M_SINF_19_18	(*((volatile unsigned long *)ADDR_M_SINF_18))
#define	MNM1221_M_SINF_21_20	(*((volatile unsigned long *)ADDR_M_SINF_20))
#define	MNM1221_M_SINF_23_22	(*((volatile unsigned long *)ADDR_M_SINF_22))
#define	MNM1221_M_SINF_25_24	(*((volatile unsigned long *)ADDR_M_SINF_24))
#define	MNM1221_M_SINF_27_26	(*((volatile unsigned long *)ADDR_M_SINF_26))
#define	MNM1221_M_SINF_29_28	(*((volatile unsigned long *)ADDR_M_SINF_28))
#define	MNM1221_M_SINF_31_30	(*((volatile unsigned long *)ADDR_M_SINF_30))

#define	MNM1221_M_MDIO_RDAT		(*((volatile unsigned long *)ADDR_M_MDIO_RDAT))
/*--------------------------------------------------------------------------*/

#endif


/*--------------------------------------------------------------------------*/
/* General definition														*/
/*--------------------------------------------------------------------------*/
#define MAX_N_SLAVE_NODE		32		/* maximum number of slave nodes */
#define	BYTE_SIZE_OF_BLOCK		16		/* size of memory block per 1node  */
#define	WORD_SIZE_OF_BLOCK		(BYTE_SIZE_OF_BLOCK / 2)
#define	DWORD_SIZE_OF_BLOCK		(BYTE_SIZE_OF_BLOCK / 4)

/*--------------------------------------------------------------------------*/
/* Definition of bit field													*/
/*--------------------------------------------------------------------------*/
/*
* It is necessary to confirm whether the other file does not include the same
* definition because of using short name.
*/

/* MNM1221_M_STATE register */
#define	MSK_FRM_ID			0xff00		/* Frame ID */
#define	B_INITIAL			0x0008		/* INITIAL state */
#define	B_RING_CFG			0x0004		/* RING CONFIG state */
#define	B_READY				0x0002		/* READY state */
#define	B_RUNNING			0x0001		/* RUNNING state */
#define	MSK_STATE			(B_INITIAL | B_RING_CFG | B_READY | B_RUNNING)

/* MNM1221_M_SINF register */
/* for 16bit definition only
* bit15    --> presence (0: disable or inactive, 1: enable or active)
* bit14:13 --> mode (1: servo, 2: input module, 3: output module)
* bit12:8  --> MACID (0 to 31)
* bit7:6   --> not used
* bit5:0   --> the number of occupied blocks (normally 1)
*/
#define	B_ACTIVE			0x8000
#define	MSK_MODE			0x6000
#define	MSK_MACID			0x1f00
#define	MSK_N_BLK			0x003f
/*--------------------------------------------------------------------------*/


/***************************************************** End of mnm1221_m.h ***/
